@@ -20,7 +20,7 @@ class MovingIntelligence:
         self.utilities = Utilities(username, apikey)
 
     def get_devices(self) -> dict:
-        """Get objects."""
+        """Get devices."""
         result = []
 
         objects = self.utilities.request(
@@ -28,9 +28,9 @@ class MovingIntelligence:
             endpoint="/v1/objects",
         )
 
-        for object in objects:
-            device = Device(self.utilities, object["licence"])
-            device.update_from_json(object)
+        for item in objects:
+            device = Device(self.utilities, item["licence"])
+            device.update_from_json(item)
             if device.odo:
                 result.append(device)
 
@@ -98,20 +98,20 @@ class Device:
             "last_seen": self.last_seen,
         }
 
-    def update_from_json(self, json_device):
+    def update_from_json(self, data):
         """Set all attributes based on API response."""
-        self.identifier = json_device["id"]
-        self.license_plate = json_device["licence"]
-        self.make = json_device["brand"]
-        self.model = json_device["model"]
-        self.chassisnumber = json_device["chassisNumber"]
-        if "startDate" in json_device:
-            start = datetime.datetime.fromtimestamp(json_device["startDate"])
+
+        self.identifier = self.getvalue(data, "id")
+        self.license_plate = self.getvalue(data, "licence")
+        self.make = self.getvalue(data, "brand")
+        self.model = self.getvalue(data, "model")
+        self.chassisnumber = self.getvalue(data, "chassisNumber")
+        if "startDate" in data:
+            start = datetime.datetime.fromtimestamp(data["startDate"])
             self.startdate = start.strftime("%Y-%m-%d %H:%M:%S")
-        if "yearOfManufacture" in json_device:
-            self.year = json_device["yearOfManufacture"]
-        if "remarks" in json_device:
-            self.remarks = json_device["remarks"]
+
+        self.year = self.getvalue(data, "yearOfManufacture")
+        self.remarks = self.getvalue(data, "remarks")
         self.odo = self.get_odometer(self.identifier)
 
         trip = self.get_object_detailed_trips(
@@ -125,32 +125,37 @@ class Device:
                 self.longitude = float(location[-1]["lon"] / 1000000)
                 self.speed = location[-1]["speed"]
 
-            self.street = trip[-1]["endRoad"]
-            self.city = trip[-1]["endCity"]
-            self.country = trip[-1]["endCountry"]
-            self.last_distance = trip[-1]["distance"] / 1000
-            if trip[-1]["endDate"]:
+            self.street = self.getvalue(trip[-1], "endRoad")
+            self.city = self.getvalue(trip[-1], "endCity")
+            self.country = self.getvalue(trip[-1], "endCountry")
+            self.last_distance = self.getvalue(trip[-1], "distance") / 1000
+            if "endDate" in trip[-1]:
                 when = datetime.datetime.fromtimestamp(trip[-1]["endDate"])
                 self.last_seen = when.strftime("%Y-%m-%d %H:%M:%S")
 
+    @staticmethod
+    def getvalue(data, value):
+        """Safely get values."""
+        if value in data:
+            return data[value]
+        return None
 
-    def get_odometer(self, object_id: str, date=None) -> dict:
+    def get_odometer(self, object_id: str) -> dict:
         """Get odometer readings."""
 
         odometer = None
         data = self._utilities.request(
-            "GET",
-            endpoint=f"/v1/object/{object_id}/odometer",
-            params=self._utilities.clean_request_params({"date": date}),
+            "GET", endpoint=f"/v1/object/{object_id}/odometer"
         )
 
         if data:
-            odometer = int(data["odoInMeters"] / 1000)
+            odometer = int(self.getvalue(data, "odoInMeters") / 1000)
 
         return odometer
 
     def get_object_detailed_trips(
-        self, object_id: str, period: str, classifications) -> dict:
+        self, object_id: str, period: str, classifications
+    ) -> dict:
         """Get detailed trips for object."""
 
         return self._utilities.request(
